/*
 * WlAppShell-xrm.h
 *	Standard XrmOptionDescRec list for WlAppShell resources.
 *
 * Copyright (C) 1997 Eric A. Howe
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Authors:	Matthew D. Francey
 *		Eric A. Howe (mu@trends.net)
 **
 * $Mu: wlib/wlib/WlAppShell-xrm.h,v 1.7 $
 */
	{"-depth",	"*wlDepth",		XrmoptionSepArg, NULL},
	{"-editres",	"*wlUseEditRes",	XrmoptionNoArg,  "True"},
	{"-install",	"*wlUsePrivateColormap",XrmoptionNoArg,	"True"},
	{"-noeditres",	"*wlUseEditRes",	XrmoptionNoArg,  "False"},
	{"-noinstall",	"*wlUsePrivateColormap",XrmoptionNoArg,	"True"},
	{"-noprivatecm","*wlUsePrivateColormap",XrmoptionNoArg,  "False"},
	{"-privatecm",	"*wlUsePrivateColormap",XrmoptionNoArg,  "True"},
	{"-visual",	"*wlVisualClass",	XrmoptionSepArg, NULL},
	{"-visualid",	"*wlVisualID",		XrmoptionSepArg, NULL},
